summaryrefslogtreecommitdiffhomepage
path: root/pkg/syncevent/waiter_amd64.s
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/syncevent/waiter_amd64.s')
-rw-r--r--pkg/syncevent/waiter_amd64.s4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkg/syncevent/waiter_amd64.s b/pkg/syncevent/waiter_amd64.s
index 985b56ae5..5e216b045 100644
--- a/pkg/syncevent/waiter_amd64.s
+++ b/pkg/syncevent/waiter_amd64.s
@@ -16,9 +16,9 @@
// See waiter_noasm_unsafe.go for a description of waiterUnlock.
//
// func waiterUnlock(g unsafe.Pointer, wg *unsafe.Pointer) bool
TEXT ·waiterUnlock(SB),NOSPLIT,$0-24
- MOVQ g+0(FP), DI
+ MOVQ ptr+0(FP), DI
MOVQ wg+8(FP), SI
MOVQ $·preparingG(SB), AX
@@ -16,9 +16,9 @@
// See waiter_noasm_unsafe.go for a description of waiterUnlock.
//
-// func waiterUnlock(g unsafe.Pointer, wg *unsafe.Pointer) bool
+// func waiterUnlock(ptr unsafe.Pointer, wg *unsafe.Pointer) bool
TEXT ·waiterUnlock(SB),NOSPLIT,$0-24